@@ -1,6 +1,6 @@
 /*
  *  Notes - panel plugin for Xfce Desktop Environment
- *  Copyright (c) 2006-2008  Mike Massonnet <mmassonnet@gmail.com>
+ *  Copyright (c) 2006-2009  Mike Massonnet <mmassonnet@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 
 #include "defines.h"
 #include "notes.h"
+#include "xfce-arrow-button.h"
 
 #define PLUGIN_NAME "xfce4-notes-plugin"
 #define OPAQUE 0xffffffff
@@ -66,8 +67,6 @@ static void             notes_window_set_sos_last_state (NotesWindow *notes_wind
 
 static void             notes_window_set_tabs           (NotesWindow *notes_window);
 
-static void             notes_window_set_statusbar      (NotesWindow *notes_window);
-
 static void             notes_window_set_above          (NotesWindow *notes_window);
 
 static void             notes_window_set_sticky         (NotesWindow *notes_window);
@@ -76,6 +75,12 @@ static void             notes_window_set_font_dialog    (NotesWindow *notes_wind
 
 static void             notes_window_set_transparency   (NotesWindow *notes_window,
                                                          gint transparency);
+static gboolean         notes_window_leave_event        (NotesWindow *notes_window,
+                                                         GdkEventCrossing *event);
+static gboolean         notes_window_motion_event       (NotesWindow *notes_window,
+                                                         GdkEventMotion *event);
+static gboolean         notes_window_button_event       (NotesWindow *notes_window,
+                                                         GdkEventButton *event);
 static gboolean         notes_window_state_event        (NotesWindow *notes_window,
                                                          GdkEventWindowState *event);
 static gboolean         notes_window_title_press        (NotesWindow *notes_window,
@@ -171,7 +176,8 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
   DBG ("New window: %s", window_name);
 
   NotesWindow          *notes_window;
-  GtkWidget            *img_add, *img_del, *img_close, *arrow_menu;
+  GtkWidget            *label, *arrow_menu;
+  GtkRcStyle           *style;
   gchar                *window_name_tmp;
   gchar                *accel_name;
 
@@ -201,10 +207,15 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
   gtk_window_set_decorated (GTK_WINDOW (notes_window->window), FALSE);
   gtk_window_set_icon_name (GTK_WINDOW (notes_window->window), "xfce4-notes-plugin");
   gtk_widget_set_name (notes_window->window, PLUGIN_NAME);
+  gtk_widget_add_events (notes_window->window, GDK_POINTER_MOTION_MASK|GDK_POINTER_MOTION_HINT_MASK|GDK_BUTTON_PRESS_MASK);
 
   /* Frame */
   notes_window->frame = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (notes_window->frame), GTK_SHADOW_OUT);
+  gtk_frame_set_shadow_type (GTK_FRAME (notes_window->frame), GTK_SHADOW_NONE);
+  style = gtk_widget_get_modifier_style (notes_window->frame);
+  style->xthickness = 1;
+  style->ythickness = 3;
+  gtk_widget_modify_style (notes_window->frame, style);
   gtk_container_add (GTK_CONTAINER (notes_window->window),
                      notes_window->frame);
   gtk_widget_show (notes_window->frame);
@@ -228,9 +239,9 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
   /* Add button */
   notes_window->btn_add = xfce_create_panel_button ();
   gtk_widget_set_size_request (notes_window->btn_add, 22, 22);
-  img_add = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU);
-  gtk_container_add (GTK_CONTAINER (notes_window->btn_add),
-                     img_add);
+  label = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (label), "<b>+</b>");
+  gtk_container_add (GTK_CONTAINER (notes_window->btn_add), label);
   gtk_box_pack_start (GTK_BOX (notes_window->hbox),
                       notes_window->btn_add,
                       FALSE,
@@ -241,9 +252,9 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
   /* Remove button */
   notes_window->btn_del = xfce_create_panel_button ();
   gtk_widget_set_size_request (notes_window->btn_del, 22, 22);
-  img_del = gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
-  gtk_container_add (GTK_CONTAINER (notes_window->btn_del),
-                     img_del);
+  label = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (label), "<b>−</b>");
+  gtk_container_add (GTK_CONTAINER (notes_window->btn_del), label);
   gtk_box_pack_start (GTK_BOX (notes_window->hbox),
                       notes_window->btn_del,
                       FALSE,
@@ -272,11 +283,10 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
   gtk_widget_show (notes_window->title);
 
   /* Menu button */
-  notes_window->btn_menu = xfce_create_panel_toggle_button ();
+  notes_window->btn_menu = xfce_arrow_button_new (GTK_ARROW_DOWN);
+  gtk_button_set_relief (GTK_BUTTON (notes_window->btn_menu), GTK_RELIEF_NONE);
   gtk_widget_set_size_request (notes_window->btn_menu, 22, 22);
-  arrow_menu = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
-  gtk_container_add (GTK_CONTAINER (notes_window->btn_menu),
-                     arrow_menu);
+  g_object_set (notes_window->btn_menu, "can-focus", FALSE, NULL);
   gtk_box_pack_start (GTK_BOX (notes_window->hbox),
                       notes_window->btn_menu,
                       FALSE,
@@ -287,9 +297,9 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
   /* Close button */
   notes_window->btn_close = xfce_create_panel_button ();
   gtk_widget_set_size_request (notes_window->btn_close, 22, 22);
-  img_close = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-  gtk_container_add (GTK_CONTAINER (notes_window->btn_close),
-                     img_close);
+  label = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (label), "<b>×</b>");
+  gtk_container_add (GTK_CONTAINER (notes_window->btn_close), label);
   gtk_box_pack_start (GTK_BOX (notes_window->hbox),
                       notes_window->btn_close,
                       FALSE,
@@ -309,14 +319,6 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
                       0);
   gtk_widget_show (notes_window->notebook);
 
-  /* Status bar */
-  notes_window->statusbar = gtk_statusbar_new ();
-  gtk_box_pack_start (GTK_BOX (notes_window->vbox),
-                      notes_window->statusbar,
-                      FALSE,
-                      FALSE,
-                      0);
-
   /* Accel group */
   notes_window->accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (notes_window->window),
@@ -381,6 +383,18 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
 #endif
 
   /* Signals */
+  g_signal_connect_swapped (notes_window->window,
+                            "leave-notify-event",
+                            G_CALLBACK (notes_window_leave_event),
+                            notes_window);
+  g_signal_connect_swapped (notes_window->window,
+                            "motion-notify-event",
+                            G_CALLBACK (notes_window_motion_event),
+                            notes_window);
+  g_signal_connect_swapped (notes_window->window,
+                            "button-press-event",
+                            G_CALLBACK (notes_window_button_event),
+                            notes_window);
   g_signal_connect_swapped (notes_window->window,
                             "window-state-event",
                             G_CALLBACK (notes_window_state_event),
@@ -419,9 +433,6 @@ notes_window_new_with_label (NotesPlugin *notes_plugin,
                             notes_window);
 
   /* Show the stuff, or not */
-  if (G_UNLIKELY (notes_window->show_statusbar))
-    gtk_widget_show (notes_window->statusbar);
-
   if (G_LIKELY (notes_window->show_on_startup == ALWAYS
                 || (notes_window->visible
                     && notes_window->show_on_startup == LAST_STATE)))
@@ -501,9 +512,9 @@ notes_window_load_data (NotesWindow *notes_window)
   const gchar          *note_name;
   gint                  w = NEW_WINDOW_WIDTH;
   gint                  h = NEW_WINDOW_HEIGHT;
+  gint                  last_tab;
   gboolean              above = NEW_WINDOW_ABOVE;
   ShowOnStartup         show_on_startup = LAST_STATE;
-  gboolean              show_statusbar = NEW_WINDOW_RESIZE_GRIP;
   gboolean              show_tabs = NEW_WINDOW_TABS;
   gboolean              sticky = NEW_WINDOW_STICKY;
   gint                  transparency = NEW_WINDOW_TRANSPARENCY;
@@ -544,7 +555,6 @@ notes_window_load_data (NotesWindow *notes_window)
   h =               xfconf_channel_get_int  (notes_plugin->xfconf_channel, "/new_window/height", h);
   above =           xfconf_channel_get_bool (notes_plugin->xfconf_channel, "/new_window/always_on_top", above);
   show_on_startup = xfconf_channel_get_bool (notes_plugin->xfconf_channel, "/new_window/show_on_startup", show_on_startup);
-  show_statusbar =  xfconf_channel_get_bool (notes_plugin->xfconf_channel, "/new_window/show_resize_grip", show_statusbar);
   show_tabs =       xfconf_channel_get_bool (notes_plugin->xfconf_channel, "/new_window/show_tabs", show_tabs);
   sticky =          xfconf_channel_get_bool (notes_plugin->xfconf_channel, "/new_window/sticky", sticky);
   visible =         xfconf_channel_get_bool (notes_plugin->xfconf_channel, "/new_window/visible", visible);
@@ -560,10 +570,10 @@ notes_window_load_data (NotesWindow *notes_window)
   notes_window->y = xfce_rc_read_int_entry (rc, "PosY", -1);
   notes_window->w = xfce_rc_read_int_entry (rc, "Width", w);
   notes_window->h = xfce_rc_read_int_entry (rc, "Height", h);
+  last_tab = xfce_rc_read_int_entry (rc, "LastTab", 0);
 
   notes_window->above           = xfce_rc_read_bool_entry (rc, "Above", above);
   notes_window->show_on_startup = xfce_rc_read_int_entry (rc, "ShowOnStartup", show_on_startup);
-  notes_window->show_statusbar  = xfce_rc_read_bool_entry (rc, "ShowStatusbar", show_statusbar);
   notes_window->show_tabs       = xfce_rc_read_bool_entry (rc, "ShowTabs", show_tabs);
   notes_window->sticky          = xfce_rc_read_bool_entry (rc, "Sticky", sticky);
   notes_window->visible         = xfce_rc_read_bool_entry (rc, "Visible", visible);
@@ -577,7 +587,6 @@ notes_window_load_data (NotesWindow *notes_window)
        "\ngeometry: %d/%d:%dx%d"
        "\nabove: %d"
        "\nshow_on_startup: %d"
-       "\nshow_statusbar: %d"
        "\nshow_tabs: %d"
        "\nsticky: %d"
        "\nvisible: %d"
@@ -586,7 +595,6 @@ notes_window_load_data (NotesWindow *notes_window)
        notes_window->x, notes_window->y, notes_window->w, notes_window->h,
        notes_window->above,
        notes_window->show_on_startup,
-       notes_window->show_statusbar,
        notes_window->show_tabs,
        notes_window->sticky,
        notes_window->visible,
@@ -606,15 +614,17 @@ notes_window_load_data (NotesWindow *notes_window)
   while (G_LIKELY (NULL != note_name));
 
   notes_window_set_transparency (notes_window, notes_window->transparency);
-  gtk_notebook_set_current_page (GTK_NOTEBOOK (notes_window->notebook), 0);
-  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notes_window->notebook), notes_window->show_tabs);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (notes_window->notebook), last_tab);
+  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notes_window->notebook),
+                              (notes_window->show_tabs && g_slist_length (notes_window->notes) > 1));
   gtk_notebook_set_show_border (GTK_NOTEBOOK (notes_window->notebook), FALSE);
 }
 
 void
 notes_window_save_data (NotesWindow *notes_window)
 {
-  XfceRc               *rc;
+  XfceRc *rc;
+  gint last_tab;
 
   rc = xfce_rc_simple_open (notes_window->notes_plugin->config_file, FALSE);
   g_return_if_fail (G_LIKELY (rc != NULL));
@@ -635,16 +645,16 @@ notes_window_save_data (NotesWindow *notes_window)
                              NULL);
     }
 
+  last_tab = gtk_notebook_get_current_page (GTK_NOTEBOOK (notes_window->notebook));
+
   TRACE ("\nabove: %d"
          "\nshow_on_startup: %d"
-         "\nshow_statusbar: %d"
          "\nshow_tabs: %d"
          "\nsticky: %d"
          "\nvisible: %d"
          "\ntransparency: %d",
          notes_window->above,
          notes_window->show_on_startup,
-         notes_window->show_statusbar,
          notes_window->show_tabs,
          notes_window->sticky,
          notes_window->visible,
@@ -654,10 +664,10 @@ notes_window_save_data (NotesWindow *notes_window)
   xfce_rc_write_int_entry (rc, "PosY", notes_window->y);
   xfce_rc_write_int_entry (rc, "Width", notes_window->w);
   xfce_rc_write_int_entry (rc, "Height", notes_window->h);
+  xfce_rc_write_int_entry (rc, "LastTab", last_tab);
 
   xfce_rc_write_bool_entry (rc, "Above", notes_window->above);
   xfce_rc_write_int_entry  (rc, "ShowOnStartup", notes_window->show_on_startup);
-  xfce_rc_write_bool_entry (rc, "ShowStatusbar", notes_window->show_statusbar);
   xfce_rc_write_bool_entry (rc, "ShowTabs", notes_window->show_tabs);
   xfce_rc_write_bool_entry (rc, "Sticky", notes_window->sticky);
   xfce_rc_write_bool_entry (rc, "Visible", GTK_WIDGET_VISIBLE (notes_window->window));
@@ -746,40 +756,41 @@ notes_window_menu_new (NotesWindow *notes_window)
   /* Menu */
   notes_window->menu = gtk_menu_new ();
   GtkWidget *mi_window         = gtk_menu_item_new_with_label (_("Window"));
-  GtkWidget *mi_separator1     = gtk_separator_menu_item_new ();
   GtkWidget *mi_new_window     = gtk_image_menu_item_new_from_stock (GTK_STOCK_NEW, NULL);
   GtkWidget *mi_destroy_window = gtk_image_menu_item_new_from_stock (GTK_STOCK_DELETE, NULL);
   GtkWidget *mi_rename_window  = gtk_menu_item_new_with_mnemonic (_("_Rename..."));
   GtkWidget *mi_font           = gtk_image_menu_item_new_from_stock (GTK_STOCK_SELECT_FONT, NULL);
   notes_window->mi_options     = gtk_menu_item_new_with_mnemonic (_("_Options"));
-  GtkWidget *mi_separator2     = gtk_separator_menu_item_new ();
+  GtkWidget *mi_separator1     = gtk_separator_menu_item_new ();
   GtkWidget *mi_note           = gtk_menu_item_new_with_label (_("Note"));
-  GtkWidget *mi_separator3     = gtk_separator_menu_item_new ();
   GtkWidget *mi_new_note       = gtk_image_menu_item_new_from_stock (GTK_STOCK_NEW, NULL);
   GtkWidget *mi_delete_note    = gtk_image_menu_item_new_from_stock (GTK_STOCK_DELETE, NULL);
   GtkWidget *mi_rename_note    = gtk_menu_item_new_with_mnemonic (_("R_ename..."));
-  /*GtkWidget *mi_lock_note      = gtk_menu_item_new_with_mnemonic (_("_Lock note"));*/
+#if 0
+  GtkWidget *mi_lock_note      = gtk_menu_item_new_with_mnemonic ( ("_Lock note"));
+#endif
   GtkWidget *mi_undo           = gtk_image_menu_item_new_from_stock (GTK_STOCK_UNDO, NULL);
 
   gtk_widget_set_sensitive (mi_window, FALSE);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_window);
-  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_separator1);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_new_window);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_destroy_window);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_rename_window);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_font);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), notes_window->mi_options);
-  gtk_menu_attach_to_widget (GTK_MENU (notes_window->menu), notes_window->btn_menu, NULL);
-  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_separator2);
-  gtk_widget_set_sensitive (mi_note, FALSE);
+  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_separator1);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_note);
-  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_separator3);
+  gtk_widget_set_sensitive (mi_note, FALSE);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_new_note);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_delete_note);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_rename_note);
-  /*gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_lock_note);*/
+#if 0
+  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_lock_note);
+#endif
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu), mi_undo);
 
+  gtk_menu_attach_to_widget (GTK_MENU (notes_window->menu), notes_window->btn_menu, NULL);
+
   /* Accel group */
   gtk_menu_set_accel_group (GTK_MENU (notes_window->menu),
                             notes_window->accel_group);
@@ -875,45 +886,42 @@ notes_window_menu_options_new (NotesWindow *notes_window)
 
   /* NotesWindow options menu */
   notes_window->menu_options = gtk_menu_new ();
-  GtkWidget *mi_show_statusbar  = gtk_check_menu_item_new_with_label (_("Resize grip"));
   GtkWidget *mi_above           = gtk_check_menu_item_new_with_label (_("Always on top"));
   GtkWidget *mi_sticky          = gtk_check_menu_item_new_with_label (_("Sticky window"));
-  GtkWidget *mi_hide_tabs       = gtk_check_menu_item_new_with_label (_("Hide tabs"));
+  GtkWidget *mi_show_tabs       = gtk_check_menu_item_new_with_label (_("Show tabs"));
+  GtkWidget *mi_separator1      = gtk_separator_menu_item_new ();
   GtkWidget *mi_show_on_startup = gtk_menu_item_new_with_label (_("Show on startup"));
 
-  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_show_statusbar);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_above);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_sticky);
-  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_hide_tabs);
+  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_show_tabs);
+  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_separator1);
   gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_show_on_startup);
+  gtk_widget_set_sensitive (mi_show_on_startup, FALSE);
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (notes_window->mi_options), notes_window->menu_options);
 
-  /* Sub-menu "Show on startup" */
-  GtkWidget *menu_show_on_startup = gtk_menu_new ();
   GSList *menu_group = NULL;
-  GtkWidget *mi_sos_always      = gtk_radio_menu_item_new_with_label (menu_group, _("Always"));
+
+  GtkWidget *mi_sos_always = gtk_radio_menu_item_new_with_label (menu_group, _("Always"));
   menu_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (mi_sos_always));
-  GtkWidget *mi_sos_never       = gtk_radio_menu_item_new_with_label (menu_group, _("Never"));
+  GtkWidget *mi_sos_never = gtk_radio_menu_item_new_with_label (menu_group, _("Never"));
   menu_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (mi_sos_never));
-  GtkWidget *mi_sos_last_state  = gtk_radio_menu_item_new_with_label (menu_group, _("Last state"));
+  GtkWidget *mi_sos_last_state = gtk_radio_menu_item_new_with_label (menu_group, _("Last state"));
   menu_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (mi_sos_last_state));
 
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu_show_on_startup), mi_sos_always);
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu_show_on_startup), mi_sos_never);
-  gtk_menu_shell_append (GTK_MENU_SHELL (menu_show_on_startup), mi_sos_last_state);
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (mi_show_on_startup), menu_show_on_startup);
+  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_sos_always);
+  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_sos_never);
+  gtk_menu_shell_append (GTK_MENU_SHELL (notes_window->menu_options), mi_sos_last_state);
 
   /* Activate check menu items */
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_sos_always),
-                                  (notes_window->show_on_startup == ALWAYS));
+                                  notes_window->show_on_startup == ALWAYS);
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_sos_never),
-                                  (notes_window->show_on_startup == NEVER));
+                                  notes_window->show_on_startup == NEVER);
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_sos_last_state),
-                                  (notes_window->show_on_startup == LAST_STATE));
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_hide_tabs),
-                                  !notes_window->show_tabs);
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_show_statusbar),
-                                  notes_window->show_statusbar);
+                                  notes_window->show_on_startup == LAST_STATE);
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_show_tabs),
+                                  notes_window->show_tabs);
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_above),
                                   notes_window->above);
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi_sticky),
@@ -924,7 +932,7 @@ notes_window_menu_options_new (NotesWindow *notes_window)
   /* Accel group */
   gtk_menu_set_accel_group (GTK_MENU (notes_window->menu_options),
                             notes_window->accel_group);
-  gtk_widget_add_accelerator (mi_hide_tabs,
+  gtk_widget_add_accelerator (mi_show_tabs,
                               "activate",
                               notes_window->accel_group,
                               GDK_F12,
@@ -945,14 +953,10 @@ notes_window_menu_options_new (NotesWindow *notes_window)
                             "activate",
                             G_CALLBACK (notes_window_set_sos_last_state),
                             notes_window);
-  g_signal_connect_swapped (mi_hide_tabs,
+  g_signal_connect_swapped (mi_show_tabs,
                             "activate",
                             G_CALLBACK (notes_window_set_tabs),
                             notes_window);
-  g_signal_connect_swapped (mi_show_statusbar,
-                            "activate",
-                            G_CALLBACK (notes_window_set_statusbar),
-                            notes_window);
   g_signal_connect_swapped (mi_above,
                             "activate",
                             G_CALLBACK (notes_window_set_above),
@@ -1054,19 +1058,6 @@ notes_window_set_tabs (NotesWindow *notes_window)
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notes_window->notebook), notes_window->show_tabs);
 }
 
-static void
-notes_window_set_statusbar (NotesWindow *notes_window)
-{
-  if (!GTK_WIDGET_VISIBLE (notes_window->notebook))
-    notes_window_unshade (notes_window);
-
-  notes_window->show_statusbar = !notes_window->show_statusbar;
-  if (notes_window->show_statusbar)
-    gtk_widget_show (notes_window->statusbar);
-  else
-    gtk_widget_hide (notes_window->statusbar);
-}
-
 static void
 notes_window_set_above (NotesWindow *notes_window)
 {
@@ -1130,6 +1121,138 @@ notes_window_set_transparency (NotesWindow *notes_window,
   gdk_error_trap_pop ();
 }
 
+/**
+ * Window motion/button event to allow resizing
+ */
+static gboolean
+notes_window_leave_event (NotesWindow *notes_window,
+                          GdkEventCrossing *event)
+{
+  gdk_window_set_cursor (notes_window->window->window, NULL);
+}
+
+static gboolean
+notes_window_motion_event (NotesWindow *notes_window,
+                           GdkEventMotion *event)
+{
+  GtkAllocation     alloc = notes_window->window->allocation;
+  GdkCursor        *cursor;
+
+  if (event->x > 2 &&
+      event->y > 2 &&
+      event->x < alloc.width - 2 &&
+      event->y < alloc.height - 3)
+      return FALSE;
+
+  TRACE ("Window Motion: (%.0fx%.0f) %dx%d", event->x, event->y, alloc.width, alloc.height);
+
+  /* Display a mouse cursor for the bottom right corner */
+  if (event->x >= alloc.width - CORNER_MARGIN &&
+      event->y >= alloc.height - CORNER_MARGIN)
+    {
+      cursor = gdk_cursor_new (GDK_BOTTOM_RIGHT_CORNER);
+      gdk_window_set_cursor (notes_window->window->window, cursor);
+      gdk_cursor_unref (cursor);
+    }
+  /* Display a mouse cursor for the bottom line */
+  else if (event->x > CORNER_MARGIN &&
+           event->y > alloc.height - CORNER_MARGIN &&
+           event->x < alloc.width - CORNER_MARGIN)
+    {
+      cursor = gdk_cursor_new (GDK_BOTTOM_SIDE);
+      gdk_window_set_cursor (notes_window->window->window, cursor);
+      gdk_cursor_unref (cursor);
+    }
+  /* Display a mouse cursor for the bottom left corner */
+  else if (event->x <= CORNER_MARGIN &&
+           event->y >= alloc.height - CORNER_MARGIN)
+    {
+      cursor = gdk_cursor_new (GDK_BOTTOM_LEFT_CORNER);
+      gdk_window_set_cursor (notes_window->window->window, cursor);
+      gdk_cursor_unref (cursor);
+    }
+  else
+    {
+      gdk_window_set_cursor (notes_window->window->window, NULL);
+    }
+
+  return TRUE;
+}
+
+static gboolean
+notes_window_button_event (NotesWindow *notes_window,
+                           GdkEventButton *event)
+{
+  GtkAllocation alloc = notes_window->window->allocation;
+  GdkWindowEdge edge;
+
+  if (event->x > 2 &&
+      event->y > 2 &&
+      event->x < alloc.width - 2 &&
+      event->y < alloc.height - 3)
+    return FALSE;
+
+  /* Top Left corner */
+  if (event->x <= CORNER_MARGIN &&
+      event->y <= CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_NORTH_WEST;
+    }
+  /* Top line */
+  else if (event->x > CORNER_MARGIN &&
+           event->y < CORNER_MARGIN &&
+           event->x < alloc.width - CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_NORTH;
+    }
+  /* Top Right corner */
+  else if (event->x >= alloc.width - CORNER_MARGIN &&
+           event->y <= CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_NORTH_EAST;
+    }
+  /* Right line */
+  else if (event->y > CORNER_MARGIN &&
+           event->x > alloc.width - CORNER_MARGIN &&
+           event->y < alloc.height - CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_EAST;
+    }
+  /* Bottom Right corner */
+  else if (event->x >= alloc.width - CORNER_MARGIN &&
+           event->y >= alloc.height - CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_SOUTH_EAST;
+    }
+  /* Bottom line */
+  else if (event->x > CORNER_MARGIN &&
+           event->y > alloc.height - CORNER_MARGIN &&
+           event->x < alloc.width - CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_SOUTH;
+    }
+  /* Bottom Left corner */
+  else if (event->x <= CORNER_MARGIN &&
+           event->y >= alloc.height - CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_SOUTH_WEST;
+    }
+  /* Left line */
+  else if (event->y > CORNER_MARGIN &&
+           event->x < CORNER_MARGIN &&
+           event->y < alloc.height - CORNER_MARGIN)
+    {
+      edge = GDK_WINDOW_EDGE_WEST;
+    }
+  else
+    return FALSE;
+
+  gtk_window_begin_resize_drag (GTK_WINDOW (notes_window->window), edge,
+                                event->button, event->x_root, event->y_root, event->time);
+
+  return TRUE;
+}
+
 /**
  * Window state event
  */
@@ -1321,8 +1444,6 @@ notes_window_shade (NotesWindow *notes_window)
     gtk_window_get_size (GTK_WINDOW (notes_window->window),
                          &notes_window->w,
                          &notes_window->h);
-  if (G_LIKELY (notes_window->show_statusbar))
-    gtk_widget_hide (notes_window->statusbar);
   gtk_widget_hide (notes_window->notebook);
   gtk_window_resize (GTK_WINDOW (notes_window->window),
                      notes_window->w,
@@ -1335,8 +1456,6 @@ notes_window_unshade (NotesWindow *notes_window)
   gtk_widget_show (notes_window->notebook);
   GTK_WIDGET_UNSET_FLAGS (notes_window->notebook,
                           GTK_CAN_FOCUS);
-  if (notes_window->show_statusbar)
-    gtk_widget_show (notes_window->statusbar);
 
   if (GTK_WIDGET_VISIBLE (notes_window->window))
     {
@@ -1613,10 +1732,16 @@ notes_note_new (NotesWindow *notes_window,
 
   /* Text view */
   notes_note->text_view = gtk_text_view_new ();
+  g_object_set (notes_note->text_view,
+                "wrap-mode", GTK_WRAP_WORD,
+                "left-margin", 2,
+                "right-margin", 2,
+                "pixels-above-lines", 1,
+                "pixels-below-lines", 1,
+                NULL);
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (notes_note->text_view));
   gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &iter, 0);
   gtk_text_buffer_create_mark (GTK_TEXT_BUFFER (buffer), "undo-pos", &iter, FALSE);
-  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (notes_note->text_view), GTK_WRAP_WORD);
   if (NULL != notes_note->notes_window->font)
     notes_note_set_font (notes_note, notes_note->notes_window->font);
   gtk_container_add (GTK_CONTAINER (notes_note->scrolled_window),
